==> refcomp-client-0.1-sources.jar: fr/inra/refcomp/client/admin/skills/PrintSkills.java <==
/*
 * #%L
 * Refcomp :: GWT client
 * 
 * $Id: PrintSkills.java 79 2011-01-27 17:45:56Z jcouteau $
 * $HeadURL: svn+ssh://jcouteau@scm.mulcyber.toulouse.inra.fr/svnroot/refcomp/tags/refcomp-0.1/refcomp-client/src/main/java/fr/inra/refcomp/client/admin/skills/PrintSkills.java $
 * %%
 * Copyright (C) 2010 - 2011 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.client.admin.skills;

import com.google.gwt.core.client.GWT;
import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.uibinder.client.UiBinder;
import com.google.gwt.uibinder.client.UiField;
import com.google.gwt.uibinder.client.UiHandler;
import com.google.gwt.uibinder.client.UiTemplate;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.Panel;
import com.google.gwt.user.client.ui.Tree;
import com.google.gwt.user.client.ui.TreeItem;
import fr.inra.refcomp.client.admin.AdminUtil;
import fr.inra.refcomp.client.services.StorageService;
import fr.inra.refcomp.client.services.StorageServiceAsync;

/**
 * User: couteau
 * Date: 13/01/11
 */
public class PrintSkills extends Composite {

    private static final StorageServiceAsync service = GWT
            .create(StorageService.class);

    @UiTemplate("PrintSkills.ui.xml")
    interface MyUiBinder extends UiBinder<Panel, PrintSkills> {
    }

    private static final MyUiBinder binder = GWT.create(MyUiBinder.class);

    @UiField
    static Tree skillsTree;

    public PrintSkills() {
        initWidget(binder.createAndBindUi(this));

        AdminUtil.checkAdmin();

        //Tree loading at display
        TreeItem root = new TreeItem("Loading...");
        skillsTree.addItem(root);
        service.getChildrenSkill(null, new AutoLoadTreeCallback(skillsTree));
    }
}

==> refcomp-client-1.0-sources.jar: fr/inra/refcomp/client/admin/skills/PrintSkills.java <==
/*
 * #%L
 * Refcomp :: GWT client
 * 
 * $Id: PrintSkills.java 128 2011-03-07 17:12:09Z jcouteau $
 * $HeadURL: svn+ssh://jcouteau@scm.mulcyber.toulouse.inra.fr/svnroot/refcomp/tags/refcomp-1.0/refcomp-client/src/main/java/fr/inra/refcomp/client/admin/skills/PrintSkills.java $
 * %%
 * Copyright (C) 2010 - 2011 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.client.admin.skills;

import com.google.gwt.core.client.GWT;
import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.uibinder.client.UiBinder;
import com.google.gwt.uibinder.client.UiField;
import com.google.gwt.uibinder.client.UiHandler;
import com.google.gwt.uibinder.client.UiTemplate;
import com.google.gwt.user.client.History;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.FlowPanel;
import com.google.gwt.user.client.ui.Panel;
import com.google.gwt.user.client.ui.Tree;
import com.google.gwt.user.client.ui.TreeItem;
import fr.inra.refcomp.client.admin.AdminUtil;
import fr.inra.refcomp.client.services.StorageService;
import fr.inra.refcomp.client.services.StorageServiceAsync;

/**
 * User: couteau
 * Date: 13/01/11
 */
public class PrintSkills extends Composite {

    private static final StorageServiceAsync service = GWT
            .create(StorageService.class);

    @UiTemplate("PrintSkills.ui.xml")
    interface MyUiBinder extends UiBinder<Panel, PrintSkills> {
    }

    private static final MyUiBinder binder = GWT.create(MyUiBinder.class);

    @UiField
    FlowPanel skillsPanel;

    static Tree skillsTree;

    public PrintSkills() {
        initWidget(binder.createAndBindUi(this));

        GreenTree greenTree = new GreenTree();
        skillsTree = new Tree(greenTree, true);
        skillsPanel.add(skillsTree);

        service.getAllSkills(new FullTreeCallback(skillsTree));
    }
}
